@@ -57,15 +57,12 @@ import org.apache.tomcat.util.net.IPv6Utils;
 
 
 /**
- * <p>
  * Abstract implementation of the <b>Valve</b> interface that generates a web server access log with the detailed line
  * contents matching a configurable pattern. The syntax of the available patterns is similar to that supported by the
  * <a href="https://httpd.apache.org/">Apache HTTP Server</a> <code>mod_log_config</code> module.
- * </p>
  * <p>
  * Patterns for the logged message may include constant text or any of the following replacement strings, for which the
  * corresponding information from the specified Response is substituted:
- * </p>
  * <ul>
  * <li><b><code>%a</code></b> - Remote IP address
  * <li><b><code>%A</code></b> - Local IP address
@@ -98,7 +95,6 @@ import org.apache.tomcat.util.net.IPv6Utils;
  * </ul>
  * <p>
  * In addition, the caller can specify one of the following aliases for commonly utilized patterns:
- * </p>
  * <ul>
  * <li><b>common</b> - <code>%h %l %u %t "%r" %s %b</code>
  * <li><b>combined</b> - <code>%h %l %u %t "%r" %s %b "%{Referer}i" "%{User-Agent}i"</code>
@@ -107,7 +103,6 @@ import org.apache.tomcat.util.net.IPv6Utils;
  * There is also support to write information from the cookie, incoming header, the Session or something else in the
  * ServletRequest.<br>
  * It is modeled after the <a href="https://httpd.apache.org/">Apache HTTP Server</a> log configuration syntax:
- * </p>
  * <ul>
  * <li><code>%{xxx}i</code> for incoming headers
  * <li><code>%{xxx}o</code> for outgoing response headers
@@ -127,14 +122,9 @@ import org.apache.tomcat.util.net.IPv6Utils;
  * non-null value, the logging will be skipped. If the value returned from ServletRequest.getAttribute(conditionIf)
  * yields the null value, the logging will be skipped. The <code>condition</code> attribute is synonym for
  * <code>conditionUnless</code> and is provided for backwards compatibility.
- * </p>
  * <p>
  * For extended attributes coming from a getAttribute() call, it is you responsibility to ensure there are no newline or
  * control characters.
- * </p>
- * @author Jason Brittain
- * @author Takayuki Kaneko
- * @author Peter Rossbach
  */
 public abstract class AbstractAccessLogValve extends ValveBase implements AccessLog {
 
@@ -1117,7 +1107,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
             Instant requestStartInstant = Instant.from(request.getCoyoteRequest().getStartInstant());
             long frac;
             if (!usesBegin) {
-                requestStartInstant.plusNanos(time);
+                requestStartInstant = requestStartInstant.plusNanos(time);
             }
             switch (type) {
                 case CLF:
