@@ -59,8 +59,6 @@ import org.eclipse.jdt.internal.compiler.problem.DefaultProblemFactory;
 /**
  * JDT class compiler. This compiler will load source dependencies from the context classloader, reducing dramatically
  * disk access during the compilation process. Based on code from Cocoon2.
- *
- * @author Remy Maucherat
  */
 public class JDTCompiler extends org.apache.jasper.compiler.Compiler {
 
@@ -336,10 +334,12 @@ public class JDTCompiler extends org.apache.jasper.compiler.Compiler {
             } else if (opt.equals("24")) {
                 settings.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_24);
             } else if (opt.equals("25")) {
+                settings.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_25);
+            } else if (opt.equals("26")) {
                 // Constant not available in latest ECJ version shipped with
                 // Tomcat. May be supported in a snapshot build.
                 // This is checked against the actual version below.
-                settings.put(CompilerOptions.OPTION_Source, "25");
+                settings.put(CompilerOptions.OPTION_Source, "26");
             } else {
                 log.warn(Localizer.getMessage("jsp.warning.unknown.sourceVM", opt));
                 settings.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_17);
@@ -423,11 +423,14 @@ public class JDTCompiler extends org.apache.jasper.compiler.Compiler {
                 settings.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_24);
                 settings.put(CompilerOptions.OPTION_Compliance, CompilerOptions.VERSION_24);
             } else if (opt.equals("25")) {
+                settings.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_25);
+                settings.put(CompilerOptions.OPTION_Compliance, CompilerOptions.VERSION_25);
+            } else if (opt.equals("26")) {
                 // Constant not available in latest ECJ version shipped with
                 // Tomcat. May be supported in a snapshot build.
                 // This is checked against the actual version below.
-                settings.put(CompilerOptions.OPTION_TargetPlatform, "25");
-                settings.put(CompilerOptions.OPTION_Compliance, "25");
+                settings.put(CompilerOptions.OPTION_TargetPlatform, "26");
+                settings.put(CompilerOptions.OPTION_Compliance, "26");
             } else {
                 log.warn(Localizer.getMessage("jsp.warning.unknown.targetVM", opt));
                 settings.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_17);
