@@ -16,10 +16,7 @@
  */
 package jakarta.el;
 
-import java.beans.FeatureDescriptor;
-import java.beans.PropertyDescriptor;
 import java.util.ArrayList;
-import java.util.Iterator;
 
 import static org.hamcrest.MatcherAssert.assertThat;
 import static org.hamcrest.core.IsInstanceOf.instanceOf;
@@ -29,7 +26,7 @@ import org.junit.Test;
 
 import org.apache.jasper.el.ELContextImpl;
 
-public class TestBeanELResolver {
+public class TestBeanELResolver extends ELBaseTest {
 
     private static final String METHOD01_NAME = "toString";
     private static final String METHOD02_NAME = "<init>";
@@ -38,22 +35,21 @@ public class TestBeanELResolver {
     private static final String PROPERTY01_NAME = "valueA";
     private static final String PROPERTY02_NAME = "valueB";
     private static final String PROPERTY03_NAME = "name";
+    private static final String PROPERTY04_NAME = "valueC";
     private static final String PROPERTY_VALUE = "test1";
 
     @Test
     public void testBug53421() {
         ExpressionFactory factory = ExpressionFactory.newInstance();
-        ELContext context = new ELContextImpl(factory);
+        ELContext context = new ELContextImpl();
 
         Bean bean = new Bean();
 
-        ValueExpression varBean =
-            factory.createValueExpression(bean, Bean.class);
+        ValueExpression varBean = factory.createValueExpression(bean, Bean.class);
         context.getVariableMapper().setVariable("bean", varBean);
 
 
-        ValueExpression ve = factory.createValueExpression(
-                context, "${bean.valueA}", String.class);
+        ValueExpression ve = factory.createValueExpression(context, "${bean.valueA}", String.class);
         Exception e = null;
         try {
             ve.getValue(context);
@@ -64,8 +60,7 @@ public class TestBeanELResolver {
         String type = Bean.class.getName();
         @SuppressWarnings("null") // Not possible due to test above
         String msg = e.getMessage();
-        Assert.assertTrue("No reference to type [" + type +
-                "] where property cannot be found in [" + msg + "]",
+        Assert.assertTrue("No reference to type [" + type + "] where property cannot be found in [" + msg + "]",
                 msg.contains(type));
     }
 
@@ -96,7 +91,8 @@ public class TestBeanELResolver {
 
         Class<?> result = resolver.getType(context, new Bean(), PROPERTY01_NAME);
 
-        Assert.assertEquals(String.class, result);
+        // Property is read-only so should return null
+        Assert.assertNull(result);
         Assert.assertTrue(context.isPropertyResolved());
     }
 
@@ -112,8 +108,7 @@ public class TestBeanELResolver {
     }
 
     /**
-     * Tests that an exception will be thrown when a coercion cannot be
-     * performed.
+     * Tests that an exception will be thrown when a coercion cannot be performed.
      */
     @Test(expected = PropertyNotFoundException.class)
     public void testGetType05() {
@@ -166,8 +161,7 @@ public class TestBeanELResolver {
     }
 
     /**
-     * Tests that an exception will be thrown when a coercion cannot be
-     * performed.
+     * Tests that an exception will be thrown when a coercion cannot be performed.
      */
     @Test(expected = PropertyNotFoundException.class)
     public void testGetValue05() {
@@ -243,8 +237,7 @@ public class TestBeanELResolver {
     }
 
     /**
-     * Tests that an exception will be thrown when a coercion cannot be
-     * performed.
+     * Tests that an exception will be thrown when a coercion cannot be performed.
      */
     @Test(expected = PropertyNotFoundException.class)
     public void testSetValue05() {
@@ -266,8 +259,7 @@ public class TestBeanELResolver {
     }
 
     /**
-     * Tests that an exception will be thrown when the property does not have
-     * setter method.
+     * Tests that an exception will be thrown when the property does not have setter method.
      */
     @Test(expected = PropertyNotWritableException.class)
     public void testSetValue07() {
@@ -306,8 +298,7 @@ public class TestBeanELResolver {
     }
 
     /**
-     * Tests that if the BeanELResolver is constructed with readOnly the method
-     * will return always true.
+     * Tests that if the BeanELResolver is constructed with readOnly the method will return always true.
      */
     @Test
     public void testIsReadOnly03() {
@@ -350,8 +341,7 @@ public class TestBeanELResolver {
     }
 
     /**
-     * Tests that true will be returned when the property does not have setter
-     * method.
+     * Tests that true will be returned when the property does not have setter method.
      */
     @Test
     public void testIsReadOnly06() {
@@ -364,39 +354,6 @@ public class TestBeanELResolver {
         Assert.assertTrue(context.isPropertyResolved());
     }
 
-    /**
-     * Tests that a valid FeatureDescriptors are not returned if base is not
-     * Map.
-     */
-    @Test
-    public void testGetFeatureDescriptors01() {
-        BeanELResolver resolver = new BeanELResolver();
-        ELContext context = new StandardELContext(ELManager.getExpressionFactory());
-
-        Iterator<FeatureDescriptor> result = resolver.getFeatureDescriptors(context, null);
-
-        Assert.assertNull(result);
-    }
-
-    /**
-     * Tests that a valid FeatureDescriptors are returned.
-     */
-    @Test
-    public void testGetFeatureDescriptors02() {
-        BeanELResolver resolver = new BeanELResolver();
-        ELContext context = new StandardELContext(ELManager.getExpressionFactory());
-
-        Iterator<FeatureDescriptor> result = resolver.getFeatureDescriptors(context, new Bean());
-
-        while (result.hasNext()) {
-            PropertyDescriptor featureDescriptor = (PropertyDescriptor) result.next();
-            Assert.assertEquals(featureDescriptor.getPropertyType(),
-                    featureDescriptor.getValue(ELResolver.TYPE));
-            Assert.assertEquals(Boolean.TRUE,
-                    featureDescriptor.getValue(ELResolver.RESOLVABLE_AT_DESIGN_TIME));
-        }
-    }
-
     /**
      * Tests that a null context results in an NPE as per EL Javadoc.
      */
@@ -422,8 +379,8 @@ public class TestBeanELResolver {
         BeanELResolver resolver = new BeanELResolver();
         ELContext context = new StandardELContext(ELManager.getExpressionFactory());
 
-        Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), METHOD01_NAME,
-                new Class<?>[] {}, new Object[] {});
+        Object result =
+                resolver.invoke(context, new TesterBean(BEAN_NAME), METHOD01_NAME, new Class<?>[] {}, new Object[] {});
 
         Assert.assertEquals(BEAN_NAME, result);
         Assert.assertTrue(context.isPropertyResolved());
@@ -445,8 +402,7 @@ public class TestBeanELResolver {
         BeanELResolver resolver = new BeanELResolver();
         ELContext context = new StandardELContext(ELManager.getExpressionFactory());
 
-        resolver.invoke(context, new TesterBean(BEAN_NAME), METHOD02_NAME, new Class<?>[] {},
-                new Object[] {});
+        resolver.invoke(context, new TesterBean(BEAN_NAME), METHOD02_NAME, new Class<?>[] {}, new Object[] {});
     }
 
     /**
@@ -457,8 +413,7 @@ public class TestBeanELResolver {
         BeanELResolver resolver = new BeanELResolver();
         ELContext context = new StandardELContext(ELManager.getExpressionFactory());
 
-        resolver.invoke(context, new TesterBean(BEAN_NAME), METHOD03_NAME, new Class<?>[] {},
-                new Object[] {});
+        resolver.invoke(context, new TesterBean(BEAN_NAME), METHOD03_NAME, new Class<?>[] {}, new Object[] {});
     }
 
     @Test
@@ -466,8 +421,8 @@ public class TestBeanELResolver {
         BeanELResolver resolver = new BeanELResolver();
         ELContext context = new StandardELContext(ELManager.getExpressionFactory());
 
-        Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs",
-                new Class<?>[] {}, new String[] {});
+        Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs", new Class<?>[] {},
+                new String[] {});
 
         Assert.assertEquals(BEAN_NAME, result);
     }
@@ -477,8 +432,7 @@ public class TestBeanELResolver {
         BeanELResolver resolver = new BeanELResolver();
         ELContext context = new StandardELContext(ELManager.getExpressionFactory());
 
-        Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs",
-                null, null);
+        Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs", null, null);
 
         Assert.assertEquals(BEAN_NAME, result);
     }
@@ -488,8 +442,7 @@ public class TestBeanELResolver {
         BeanELResolver resolver = new BeanELResolver();
         ELContext context = new StandardELContext(ELManager.getExpressionFactory());
 
-        Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs",
-                null, new String[] {});
+        Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs", null, new String[] {});
 
         Assert.assertEquals(BEAN_NAME, result);
     }
@@ -499,8 +452,7 @@ public class TestBeanELResolver {
         BeanELResolver resolver = new BeanELResolver();
         ELContext context = new StandardELContext(ELManager.getExpressionFactory());
 
-        Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs",
-                new Class<?>[] {}, null);
+        Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs", new Class<?>[] {}, null);
 
         Assert.assertEquals(BEAN_NAME, result);
     }
@@ -510,8 +462,8 @@ public class TestBeanELResolver {
         BeanELResolver resolver = new BeanELResolver();
         ELContext context = new StandardELContext(ELManager.getExpressionFactory());
 
-        Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs",
-                new Class<?>[] { null }, new String[] { null });
+        Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs", new Class<?>[] { null },
+                new String[] { null });
 
         Assert.assertEquals(BEAN_NAME, result);
     }
@@ -521,8 +473,8 @@ public class TestBeanELResolver {
         BeanELResolver resolver = new BeanELResolver();
         ELContext context = new StandardELContext(ELManager.getExpressionFactory());
 
-        Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs",
-                null, new String[] { null });
+        Object result =
+                resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs", null, new String[] { null });
 
         Assert.assertEquals(BEAN_NAME, result);
     }
@@ -532,8 +484,8 @@ public class TestBeanELResolver {
         BeanELResolver resolver = new BeanELResolver();
         ELContext context = new StandardELContext(ELManager.getExpressionFactory());
 
-        Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs",
-                new Class<?>[] { null }, null);
+        Object result =
+                resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs", new Class<?>[] { null }, null);
 
         Assert.assertEquals(BEAN_NAME, result);
     }
@@ -615,7 +567,7 @@ public class TestBeanELResolver {
         Assert.assertEquals(BEAN_NAME, result);
     }
 
-    @Test(expected=MethodNotFoundException.class)
+    @Test(expected = MethodNotFoundException.class)
     public void testInvokeVarargsCoerce15() {
         BeanELResolver resolver = new BeanELResolver();
         ELContext context = new StandardELContext(ELManager.getExpressionFactory());
@@ -632,25 +584,23 @@ public class TestBeanELResolver {
         ELContext context = new StandardELContext(ELManager.getExpressionFactory());
 
         Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs",
-                new Class<?>[] { String.class, String.class, String.class },
-                new Object[] { "10", "11", "12" });
+                new Class<?>[] { String.class, String.class, String.class }, new Object[] { "10", "11", "12" });
 
         Assert.assertEquals(BEAN_NAME, result);
     }
 
-    @Test(expected=MethodNotFoundException.class)
+    @Test(expected = MethodNotFoundException.class)
     public void testInvokeVarargsCoerce17() {
         BeanELResolver resolver = new BeanELResolver();
         ELContext context = new StandardELContext(ELManager.getExpressionFactory());
 
         Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs",
-                new Class<?>[] { String.class, String.class },
-                new Object[] { "10", "11", "12" });
+                new Class<?>[] { String.class, String.class }, new Object[] { "10", "11", "12" });
 
         Assert.assertEquals(BEAN_NAME, result);
     }
 
-    @Test(expected=MethodNotFoundException.class)
+    @Test(expected = MethodNotFoundException.class)
     public void testInvokeVarargsCoerce18() {
         BeanELResolver resolver = new BeanELResolver();
         ELContext context = new StandardELContext(ELManager.getExpressionFactory());
@@ -674,19 +624,18 @@ public class TestBeanELResolver {
         Assert.assertEquals(BEAN_NAME, result);
     }
 
-    @Test(expected=MethodNotFoundException.class)
+    @Test(expected = MethodNotFoundException.class)
     public void testInvokeVarargsCoerce20() {
         BeanELResolver resolver = new BeanELResolver();
         ELContext context = new StandardELContext(ELManager.getExpressionFactory());
 
         Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs",
-                new Class<?>[] { String.class, String.class, String.class },
-                new Object[] { "true", "10", "11", "12" });
+                new Class<?>[] { String.class, String.class, String.class }, new Object[] { "true", "10", "11", "12" });
 
         Assert.assertEquals(BEAN_NAME, result);
     }
 
-    @Test(expected=MethodNotFoundException.class)
+    @Test(expected = MethodNotFoundException.class)
     public void testInvokeVarargsCoerce21() {
         BeanELResolver resolver = new BeanELResolver();
         ELContext context = new StandardELContext(ELManager.getExpressionFactory());
@@ -705,20 +654,18 @@ public class TestBeanELResolver {
         context.addELResolver(new StringToLongNeverFailResolver());
 
         Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs",
-                new Class<?>[] { String.class, String.class, String.class },
-                new Object[] { "AA", "BB", "CC" });
+                new Class<?>[] { String.class, String.class, String.class }, new Object[] { "AA", "BB", "CC" });
 
         Assert.assertEquals(BEAN_NAME, result);
     }
 
-    @Test(expected=MethodNotFoundException.class)
+    @Test(expected = MethodNotFoundException.class)
     public void testInvokeVarargsCoerce23() {
         BeanELResolver resolver = new BeanELResolver();
         StandardELContext context = new StandardELContext(ELManager.getExpressionFactory());
 
         Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs",
-                new Class<?>[] { String.class, String.class, String.class },
-                new Object[] { "AA", "BB", "CC" });
+                new Class<?>[] { String.class, String.class, String.class }, new Object[] { "AA", "BB", "CC" });
 
         Assert.assertEquals(BEAN_NAME, result);
     }
@@ -728,8 +675,8 @@ public class TestBeanELResolver {
         BeanELResolver resolver = new BeanELResolver();
         ELContext context = new StandardELContext(ELManager.getExpressionFactory());
 
-        Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs",
-                new Class<?>[] {}, new Object[] {});
+        Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs", new Class<?>[] {},
+                new Object[] {});
 
         Assert.assertEquals(BEAN_NAME, result);
     }
@@ -739,8 +686,7 @@ public class TestBeanELResolver {
         BeanELResolver resolver = new BeanELResolver();
         ELContext context = new StandardELContext(ELManager.getExpressionFactory());
 
-        Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs",
-                null, null);
+        Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs", null, null);
 
         Assert.assertEquals(BEAN_NAME, result);
     }
@@ -750,8 +696,7 @@ public class TestBeanELResolver {
         BeanELResolver resolver = new BeanELResolver();
         ELContext context = new StandardELContext(ELManager.getExpressionFactory());
 
-        Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs",
-                null, new Object[] {});
+        Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs", null, new Object[] {});
 
         Assert.assertEquals(BEAN_NAME, result);
     }
@@ -761,8 +706,7 @@ public class TestBeanELResolver {
         BeanELResolver resolver = new BeanELResolver();
         ELContext context = new StandardELContext(ELManager.getExpressionFactory());
 
-        Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs",
-                new Class<?>[] {}, null);
+        Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs", new Class<?>[] {}, null);
 
         Assert.assertEquals(BEAN_NAME, result);
     }
@@ -772,8 +716,8 @@ public class TestBeanELResolver {
         BeanELResolver resolver = new BeanELResolver();
         ELContext context = new StandardELContext(ELManager.getExpressionFactory());
 
-        Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs",
-                new Class<?>[] { null }, new Object[] { null });
+        Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs", new Class<?>[] { null },
+                new Object[] { null });
 
         Assert.assertEquals(BEAN_NAME, result);
     }
@@ -783,8 +727,8 @@ public class TestBeanELResolver {
         BeanELResolver resolver = new BeanELResolver();
         ELContext context = new StandardELContext(ELManager.getExpressionFactory());
 
-        Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs",
-                null, new Object[] { null });
+        Object result =
+                resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs", null, new Object[] { null });
 
         Assert.assertEquals(BEAN_NAME, result);
     }
@@ -794,8 +738,8 @@ public class TestBeanELResolver {
         BeanELResolver resolver = new BeanELResolver();
         ELContext context = new StandardELContext(ELManager.getExpressionFactory());
 
-        Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs",
-                new Class<?>[] { null }, null);
+        Object result =
+                resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs", new Class<?>[] { null }, null);
 
         Assert.assertEquals(BEAN_NAME, result);
     }
@@ -861,13 +805,14 @@ public class TestBeanELResolver {
         ELContext context = new StandardELContext(ELManager.getExpressionFactory());
 
         Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs",
-                new Class<?>[] { Integer.class, Integer.class }, new Object[] { Integer.valueOf(10), Integer.valueOf(11) });
+                new Class<?>[] { Integer.class, Integer.class },
+                new Object[] { Integer.valueOf(10), Integer.valueOf(11) });
 
         Assert.assertEquals(BEAN_NAME, result);
     }
 
     // Note: The coercion rules are that a null of any type can be coerced to a
-    //       null of *any* other type so this works.
+    // null of *any* other type so this works.
     @Test
     public void testInvokeVarargs14() {
         BeanELResolver resolver = new BeanELResolver();
@@ -879,7 +824,7 @@ public class TestBeanELResolver {
         Assert.assertEquals(BEAN_NAME, result);
     }
 
-    @Test(expected=MethodNotFoundException.class)
+    @Test(expected = MethodNotFoundException.class)
     public void testInvokeVarargs15() {
         BeanELResolver resolver = new BeanELResolver();
         ELContext context = new StandardELContext(ELManager.getExpressionFactory());
@@ -897,31 +842,31 @@ public class TestBeanELResolver {
 
         Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs",
                 new Class<?>[] { Integer.class, Integer.class, Integer.class },
-                new Object[] { Integer.valueOf(10), Integer.valueOf(11),  Integer.valueOf(12) });
+                new Object[] { Integer.valueOf(10), Integer.valueOf(11), Integer.valueOf(12) });
 
         Assert.assertEquals(BEAN_NAME, result);
     }
 
-    @Test(expected=MethodNotFoundException.class)
+    @Test(expected = MethodNotFoundException.class)
     public void testInvokeVarargs17() {
         BeanELResolver resolver = new BeanELResolver();
         ELContext context = new StandardELContext(ELManager.getExpressionFactory());
 
         Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs",
                 new Class<?>[] { Integer.class, Integer.class },
-                new Object[] { Integer.valueOf(10), Integer.valueOf(11),  Integer.valueOf(12) });
+                new Object[] { Integer.valueOf(10), Integer.valueOf(11), Integer.valueOf(12) });
 
         Assert.assertEquals(BEAN_NAME, result);
     }
 
-    @Test(expected=MethodNotFoundException.class)
+    @Test(expected = MethodNotFoundException.class)
     public void testInvokeVarargs18() {
         BeanELResolver resolver = new BeanELResolver();
         ELContext context = new StandardELContext(ELManager.getExpressionFactory());
 
         Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs",
                 new Class<?>[] { Integer.class, Integer.class, Integer.class, Integer.class },
-                new Object[] { Integer.valueOf(10), Integer.valueOf(11),  Integer.valueOf(12) });
+                new Object[] { Integer.valueOf(10), Integer.valueOf(11), Integer.valueOf(12) });
 
         Assert.assertEquals(BEAN_NAME, result);
     }
@@ -933,36 +878,51 @@ public class TestBeanELResolver {
 
         Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs",
                 new Class<?>[] { Boolean.class, Integer.class, Integer.class, Integer.class },
-                new Object[] { Boolean.TRUE, Integer.valueOf(10), Integer.valueOf(11),  Integer.valueOf(12) });
+                new Object[] { Boolean.TRUE, Integer.valueOf(10), Integer.valueOf(11), Integer.valueOf(12) });
 
         Assert.assertEquals(BEAN_NAME, result);
     }
 
-    @Test(expected=MethodNotFoundException.class)
+    @Test(expected = MethodNotFoundException.class)
     public void testInvokeVarargs20() {
         BeanELResolver resolver = new BeanELResolver();
         ELContext context = new StandardELContext(ELManager.getExpressionFactory());
 
         Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs",
                 new Class<?>[] { Boolean.class, Integer.class, Integer.class },
-                new Object[] { Boolean.TRUE, Integer.valueOf(10), Integer.valueOf(11),  Integer.valueOf(12) });
+                new Object[] { Boolean.TRUE, Integer.valueOf(10), Integer.valueOf(11), Integer.valueOf(12) });
 
         Assert.assertEquals(BEAN_NAME, result);
     }
 
-    @Test(expected=MethodNotFoundException.class)
+    @Test(expected = MethodNotFoundException.class)
     public void testInvokeVarargs21() {
         BeanELResolver resolver = new BeanELResolver();
         ELContext context = new StandardELContext(ELManager.getExpressionFactory());
 
         Object result = resolver.invoke(context, new TesterBean(BEAN_NAME), "getNameVarargs",
                 new Class<?>[] { Boolean.class, Integer.class, Integer.class, Integer.class, Integer.class },
-                new Object[] { Boolean.TRUE, Integer.valueOf(10), Integer.valueOf(11),  Integer.valueOf(12) });
+                new Object[] { Boolean.TRUE, Integer.valueOf(10), Integer.valueOf(11), Integer.valueOf(12) });
 
         Assert.assertEquals(BEAN_NAME, result);
     }
 
-    private static class Bean {
+    /**
+     * Tests that a valid property implemented by a default method is resolved.
+     */
+    @Test
+    public void testGetDefaultValue() {
+        BeanELResolver resolver = new BeanELResolver();
+        ELContext context = new StandardELContext(ELManager.getExpressionFactory());
+
+        Object result = resolver.getValue(context, new Bean(), PROPERTY04_NAME);
+
+        Assert.assertEquals("Default", result);
+        Assert.assertTrue(context.isPropertyResolved());
+    }
+
+
+    private static class Bean implements MyInterface {
 
         @SuppressWarnings("unused")
         public void setValueA(String valueA) {
@@ -970,33 +930,40 @@ public class TestBeanELResolver {
         }
     }
 
-    private void doNegativeTest(Object base, Object trigger, MethodUnderTest method,
-            boolean checkResult) {
+
+    public interface MyInterface {
+        default String getValueC() {
+            return "Default";
+        }
+    }
+
+
+    private void doNegativeTest(Object base, Object trigger, MethodUnderTest method, boolean checkResult) {
         BeanELResolver resolver = new BeanELResolver();
         ELContext context = new StandardELContext(ELManager.getExpressionFactory());
 
         Object result = null;
         switch (method) {
-        case GET_VALUE: {
-            result = resolver.getValue(context, base, trigger);
-            break;
-        }
-        case SET_VALUE: {
-            resolver.setValue(context, base, trigger, new Object());
-            break;
-        }
-        case GET_TYPE: {
-            result = resolver.getType(context, base, trigger);
-            break;
-        }
-        case INVOKE: {
-            result = resolver.invoke(context, base, trigger, new Class<?>[0], new Object[0]);
-            break;
-        }
-        default: {
-            // Should never happen
-            Assert.fail("Missing case for method");
-        }
+            case GET_VALUE: {
+                result = resolver.getValue(context, base, trigger);
+                break;
+            }
+            case SET_VALUE: {
+                resolver.setValue(context, base, trigger, new Object());
+                break;
+            }
+            case GET_TYPE: {
+                result = resolver.getType(context, base, trigger);
+                break;
+            }
+            case INVOKE: {
+                result = resolver.invoke(context, base, trigger, new Class<?>[0], new Object[0]);
+                break;
+            }
+            default: {
+                // Should never happen
+                Assert.fail("Missing case for method");
+            }
         }
 
         if (checkResult) {
@@ -1006,13 +973,16 @@ public class TestBeanELResolver {
     }
 
     private enum MethodUnderTest {
-        GET_VALUE, SET_VALUE, GET_TYPE, INVOKE
+        GET_VALUE,
+        SET_VALUE,
+        GET_TYPE,
+        INVOKE
     }
 
 
     /*
-     * Custom resolver that will always convert a string to an integer. If the
-     * provided string is not a valid integer, zero will be returned.
+     * Custom resolver that will always convert a string to an integer. If the provided string is not a valid integer,
+     * zero will be returned.
      */
     private static class StringToLongNeverFailResolver extends ELResolver {
 
@@ -1042,12 +1012,7 @@ public class TestBeanELResolver {
         }
 
         @Override
-        public Iterator<FeatureDescriptor> getFeatureDescriptors(ELContext context, Object base) {
-            return null;
-        }
-
-        @Override
-        public Object convertToType(ELContext context, Object obj, Class<?> type) {
+        public <T> T convertToType(ELContext context, Object obj, Class<T> type) {
             if (Integer.class.equals(type) && obj instanceof String) {
                 context.setPropertyResolved(true);
                 Integer result;
@@ -1056,10 +1021,11 @@ public class TestBeanELResolver {
                 } catch (NumberFormatException e) {
                     result = Integer.valueOf(0);
                 }
-                return result;
+                @SuppressWarnings("unchecked")
+                T t = (T) result;
+                return t;
             }
             return super.convertToType(context, obj, type);
         }
-
     }
 }
